@@ -149,7 +149,14 @@ class GoogleOCRFormatter(BaseFormatter):
         last_pg_end_idx = 0
         for response, page_ref in responses:
             # extract page number, eg: I1PD901350083 -> 83
-            n_pg = int(page_ref[len(vol_name):])
+            n_pg_str = page_ref[len(vol_name):]
+            if '-' in page_ref:
+                n_pg_str = page_ref.split('-')[-1]
+
+            if 'a' in n_pg_str or 'b' in n_pg_str:
+                n_pg_str = int(n_pg_str[:-1])
+            n_pg = int(n_pg_str)
+
             # extract annotation
             if not response:
                 print(f'[ERROR] Failed : {n_pg}')
